Logger

Struct Logger 

pub struct Logger;
Custom logger implementation for the hyperlane-cli.

Implements the log::Log trait to provide colored console output matching the euv CLI log format.

Implementations

Source

impl Logger

Implementation of associated functions for Logger.

pub fn init(level_filter: LevelFilter)

Initializes the global logger with the specified maximum log level.

Arguments
  • LevelFilter - The maximum log level to enable.
Source

impl Logger

pub fn new() -> Self