Crate hyperlane_cli

Crate hyperlane_cli 

hyperlane-cli

A command-line tool for Hyperlane framework.

Structs

Arc
A thread-safe reference-counting pointer. ‘Arc’ stands for ‘Atomically Reference Counted’.
Args
Parsed command line arguments
Captures
Represents the capture groups for a single match.
Command
This structure mimics the API of std::process::Command found in the standard library, but replaces functions that create a process with an asynchronous variant. The main provided asynchronous functions are spawn, status, and output.
ExitStatus
Describes the result of a process after it has terminated.
HashMap
A hash map implemented with quadratic probing and SIMD lookup.
LazyLock
A value which is initialized on the first access.
Mutex
An asynchronous Mutex-like type.
NewProjectConfig
Configuration for creating a new project
Package
Package information in monorepo
Path
A slice of a path (akin to str).
PathBuf
An owned, mutable path (akin to String).
PublishResult
Publish result for a single package
Regex
A compiled regular expression for searching Unicode haystacks.
Stdio
Describes what to do with a standard I/O stream for a child process when passed to the stdin, stdout, and stderr methods of Command.
TemplateConfig
Configuration for template generation
VecDeque
A double-ended queue implemented with a growable ring buffer.
Version
Parsed version components following semantic versioning

Enums

BumpVersionType
Types of version bumps
CommandType
Available commands
ModelSubType
Model subtypes for organizing data structures
NewError
Errors that can occur during project creation
PublishError
Error types for publish operation
TemplateError
Errors that can occur during template generation
TemplateType
Types of template components that can be generated

Statics

DERIVE_REGEX
Regex pattern to match derive attribute

Traits

FromStr
Parse a value from a string

Functions

args
Returns the arguments that this program was started with (normally passed via the command line).
create_dir_all
Recursively create a directory and all of its parent components if they are missing.
execute_bump
Read and update version in Cargo.toml
execute_fmt
Execute fmt command
execute_new
Execute new command to create a project from template
execute_publish
Execute publish command for all packages in workspace
execute_template
Execute template generation
execute_watch
Execute watch command using cargo-watch
exit
Terminates the current process with the specified exit code.
format_path
Format code at specific path
parse_args
Parse command line arguments
print_help
Print help message
print_version
Print version
read_to_string
Reads the entire contents of a file into a string.
write
Writes a slice as the entire contents of a file.