hyperlane-cli
A command-line tool for Hyperlane framework.
Structs
- Arc
- A thread-safe reference-counting pointer. ‘Arc’ stands for ‘Atomically Reference Counted’.
- Args
- Parsed command line arguments
- Captures
- Represents the capture groups for a single match.
- Command
- This structure mimics the API of
std::process::Commandfound in the standard library, but replaces functions that create a process with an asynchronous variant. The main provided asynchronous functions are spawn, status, and output. - Exit
Status - Describes the result of a process after it has terminated.
- HashMap
- A hash map implemented with quadratic probing and SIMD lookup.
- Lazy
Lock - A value which is initialized on the first access.
- Mutex
- An asynchronous
Mutex-like type. - NewProject
Config - Configuration for creating a new project
- Package
- Package information in monorepo
- Path
- A slice of a path (akin to
str). - PathBuf
- An owned, mutable path (akin to
String). - Publish
Result - Publish result for a single package
- Regex
- A compiled regular expression for searching Unicode haystacks.
- Stdio
- Describes what to do with a standard I/O stream for a child process when
passed to the
stdin,stdout, andstderrmethods ofCommand. - Template
Config - Configuration for template generation
- VecDeque
- A double-ended queue implemented with a growable ring buffer.
- Version
- Parsed version components following semantic versioning
Enums
- Bump
Version Type - Types of version bumps
- Command
Type - Available commands
- Model
SubType - Model subtypes for organizing data structures
- NewError
- Errors that can occur during project creation
- Publish
Error - Error types for publish operation
- Template
Error - Errors that can occur during template generation
- Template
Type - Types of template components that can be generated
Statics
- DERIVE_
REGEX - Regex pattern to match derive attribute
Traits
- FromStr
- Parse a value from a string
Functions
- args
- Returns the arguments that this program was started with (normally passed via the command line).
- create_
dir_ all - Recursively create a directory and all of its parent components if they are missing.
- execute_
bump - Read and update version in Cargo.toml
- execute_
fmt - Execute fmt command
- execute_
new - Execute new command to create a project from template
- execute_
publish - Execute publish command for all packages in workspace
- execute_
template - Execute template generation
- execute_
watch - Execute watch command using cargo-watch
- exit
- Terminates the current process with the specified exit code.
- format_
path - Format code at specific path
- parse_
args - Parse command line arguments
- print_
help - Print help message
- print_
version - Print version
- read_
to_ string - Reads the entire contents of a file into a string.
- write
- Writes a slice as the entire contents of a file.